@@ -3,7 +3,7 @@ package App::BloomUtils;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-05-24'; # DATE
 our $DIST = 'App-BloomUtils'; # DIST
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 use 5.010001;
 use strict;
@@ -233,6 +233,8 @@ $SPEC{bloom_filter_calculator} = {
     },
 };
 sub bloom_filter_calculator {
+    require Algorithm::BloomFilter;
+
     my %args = @_;
 
     my $num_hashes_to_bits_per_item_ratio = $args{num_hashes_to_bits_per_item_ratio};
@@ -249,10 +251,11 @@ sub bloom_filter_calculator {
     $num_hashes_to_bits_per_item_ratio //= $num_hashes / $num_bits_per_item;
 
     my $actual_num_hashes = ceil($num_hashes);
-    my $num_bits_2power = sprintf "%.6f", (log($num_bits) / log(2));
-    my $actual_num_bits = 2**ceil($num_bits_2power);
+
+    my $bloom = Algorithm::BloomFilter->new($num_bits, $actual_num_hashes);
+    my $actual_bloom_size = length($bloom->serialize);
+    my $actual_num_bits = ($actual_bloom_size - 3)*8;
     my $actual_fp_rate = (1 - exp(-$actual_num_hashes*$num_items/$actual_num_bits))**$actual_num_hashes;
-    my $actual_bloom_size = ($actual_num_bits/8) + 3;
 
     [200, "OK", {
         num_bits   => $num_bits,
@@ -297,7 +300,7 @@ App::BloomUtils - Utilities related to bloom filters
 
 =head1 VERSION
 
-This document describes version 0.004 of App::BloomUtils (from Perl distribution App-BloomUtils), released on 2020-05-24.
+This document describes version 0.005 of App::BloomUtils (from Perl distribution App-BloomUtils), released on 2020-05-24.
 
 =head1 DESCRIPTION
 
